[![Build Status](https://travis-ci.org/ArtBIT/droptopus.svg)](https://travis-ci.org/ArtBIT/droptopus) [![GitHub stars](https://img.shields.io/github/stars/ArtBIT/droptopus.svg)](https://github.com/ArtBIT/droptopus) [![GitHub license](https://img.shields.io/github/license/ArtBIT/droptopus.svg)](https://github.com/ArtBIT/droptopus) [![GitHub issues](https://img.shields.io/github/issues/ArtBIT/droptopus.svg)](https://github.com/ArtBIT/droptopus/issues)

# Droptopus
![Droptopus Logo](/droptopus/assets/droptopus.png)

Droptopus is a drag'n'drop receiver, which routes dropped objects to the designated actions.

# Dependencies 
 - python3.5+
 - pyqt5

# Installation
 `pip3 install droptopus`

# Launch
 `python3 -m droptopus &`

## Acknowledgements

Droptopus uses

- [Nokia's](http://www.nokia.com): [Qt](http://qt.nokia.com)

- [Riverbank Computing Limited's](http://www.riverbankcomputing.co.uk): [SIP](http://www.riverbankcomputing.co.uk/software/sip/intro)

- [Riverbank Computing Limited's](http://www.riverbankcomputing.co.uk): [PyQt5](http://www.riverbankcomputing.co.uk/software/pyqt/intro)

- [Icon8's](http://icons8.com): [awesome icons](http://icons8.com)

Thanks!


## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details

